@@ -5,7 +5,8 @@ Copyright (c) 2025 MakerCorn
 
 Authentication and user management system with SSO/ADFS support
 
-This software is licensed for non-commercial use only. See LICENSE file for details.
+This software is licensed for non-commercial use only.
+See LICENSE file for details.
 """
 
 import hashlib
@@ -44,6 +45,7 @@ class User:
     is_active: bool
     created_at: datetime
     last_login: Optional[datetime] = None
+    tenant_name: Optional[str] = None  # For admin views
 
 
 @dataclass
@@ -54,6 +56,7 @@ class Tenant:
     is_active: bool
     created_at: datetime
     max_users: int = 100
+    user_count: Optional[int] = None  # For admin views
 
 
 class AuthManager:
@@ -65,7 +68,7 @@ class AuthManager:
             self.dsn = os.getenv("POSTGRES_DSN")
             if not self.dsn:
                 raise ValueError(
-                    "POSTGRES_DSN environment variable must be set for Postgres."
+                    "POSTGRES_DSN environment variable must be set for " "Postgres."
                 )
         else:
             self.db_path = db_path or os.getenv("DB_PATH", "prompts.db")
@@ -150,7 +153,8 @@ class AuthManager:
                     password_hash TEXT,
                     first_name TEXT NOT NULL,
                     last_name TEXT NOT NULL,
-                    role TEXT DEFAULT 'user' CHECK (role IN ('admin', 'user', 'readonly')),
+                    role TEXT DEFAULT 'user'
+                        CHECK (role IN ('admin', 'user', 'readonly')),
                     is_active BOOLEAN DEFAULT TRUE,
                     sso_id TEXT,
                     created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
@@ -198,7 +202,8 @@ class AuthManager:
                     password_hash TEXT,
                     first_name TEXT NOT NULL,
                     last_name TEXT NOT NULL,
-                    role TEXT DEFAULT 'user' CHECK (role IN ('admin', 'user', 'readonly')),
+                    role TEXT DEFAULT 'user'
+                        CHECK (role IN ('admin', 'user', 'readonly')),
                     is_active BOOLEAN DEFAULT 1,
                     sso_id TEXT,
                     created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
@@ -266,7 +271,8 @@ class AuthManager:
                 if self.db_type == "postgres":
                     cursor.execute(
                         """
-                        INSERT INTO users (id, tenant_id, email, password_hash, first_name, last_name, role, is_active)
+                        INSERT INTO users (id, tenant_id, email, password_hash,
+                                         first_name, last_name, role, is_active)
                         VALUES (%s, %s, %s, %s, %s, %s, %s, %s)
                     """,
                         (
@@ -283,7 +289,8 @@ class AuthManager:
                 else:
                     cursor.execute(
                         """
-                        INSERT INTO users (id, tenant_id, email, password_hash, first_name, last_name, role, is_active)
+                        INSERT INTO users (id, tenant_id, email, password_hash,
+                                         first_name, last_name, role, is_active)
                         VALUES (?, ?, ?, ?, ?, ?, ?, ?)
                     """,
                         (
@@ -379,7 +386,12 @@ class AuthManager:
         role: str = "user",
         sso_id: Optional[str] = None,
     ) -> Tuple[bool, str]:
-        """Create a new user"""
+        """Create a new user
+
+        Returns:
+            Tuple[bool, str]: (success, success_message) if successful,
+                             (False, error_message) if failed
+        """
         conn = self.get_conn()
         cursor = conn.cursor()
 
@@ -436,7 +448,8 @@ class AuthManager:
             if self.db_type == "postgres":
                 cursor.execute(
                     """
-                    INSERT INTO users (id, tenant_id, email, password_hash, first_name, last_name, role, is_active, sso_id)
+                    INSERT INTO users (id, tenant_id, email, password_hash,
+                                     first_name, last_name, role, is_active, sso_id)
                     VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s)
                 """,
                     (
@@ -454,7 +467,8 @@ class AuthManager:
             else:
                 cursor.execute(
                     """
-                    INSERT INTO users (id, tenant_id, email, password_hash, first_name, last_name, role, is_active, sso_id)
+                    INSERT INTO users (id, tenant_id, email, password_hash,
+                                     first_name, last_name, role, is_active, sso_id)
                     VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
                 """,
                     (
@@ -493,7 +507,8 @@ class AuthManager:
                         SELECT u.*, t.name as tenant_name, t.subdomain
                         FROM users u
                         JOIN tenants t ON u.tenant_id = t.id
-                        WHERE u.email = %s AND t.subdomain = %s AND u.is_active = TRUE AND t.is_active = TRUE
+                        WHERE u.email = %s AND t.subdomain = %s
+                          AND u.is_active = TRUE AND t.is_active = TRUE
                     """,
                         (email, subdomain),
                     )
@@ -503,7 +518,8 @@ class AuthManager:
                         SELECT u.*, t.name as tenant_name, t.subdomain
                         FROM users u
                         JOIN tenants t ON u.tenant_id = t.id
-                        WHERE u.email = ? AND t.subdomain = ? AND u.is_active = 1 AND t.is_active = 1
+                        WHERE u.email = ? AND t.subdomain = ?
+                          AND u.is_active = 1 AND t.is_active = 1
                     """,
                         (email, subdomain),
                     )
@@ -591,6 +607,7 @@ class AuthManager:
             try:
                 conn.close()
             except Exception:
+                # Silent rollback failure is acceptable here  # nosec B110
                 pass
             return False, None, f"Authentication error: {str(e)}"
 
@@ -621,7 +638,8 @@ class AuthManager:
         if self.db_type == "postgres":
             cursor.execute(
                 """
-                INSERT INTO user_sessions (id, user_id, token_hash, expires_at, ip_address, user_agent)
+                INSERT INTO user_sessions (id, user_id, token_hash, expires_at,
+                                          ip_address, user_agent)
                 VALUES (%s, %s, %s, %s, %s, %s)
             """,
                 (session_id, user_id, token_hash, expires_at, ip_address, user_agent),
@@ -629,7 +647,8 @@ class AuthManager:
         else:
             cursor.execute(
                 """
-                INSERT INTO user_sessions (id, user_id, token_hash, expires_at, ip_address, user_agent)
+                INSERT INTO user_sessions (id, user_id, token_hash, expires_at,
+                                          ip_address, user_agent)
                 VALUES (?, ?, ?, ?, ?, ?)
             """,
                 (
@@ -781,7 +800,10 @@ class AuthManager:
             "response_mode": "query",
         }
 
-        base_url = f"https://login.microsoftonline.com/{self.entra_tenant_id}/oauth2/v2.0/authorize"
+        base_url = (
+            f"https://login.microsoftonline.com/{self.entra_tenant_id}"
+            "/oauth2/v2.0/authorize"
+        )
         return f"{base_url}?{urlencode(params)}"
 
     def handle_sso_callback(
@@ -833,7 +855,8 @@ class AuthManager:
                 cursor = conn.cursor()
                 if self.db_type == "postgres":
                     cursor.execute(
-                        "SELECT id FROM tenants WHERE subdomain = %s AND is_active = TRUE",
+                        "SELECT id FROM tenants WHERE subdomain = %s "
+                        "AND is_active = TRUE",
                         (subdomain,),
                     )
                 else:
@@ -862,7 +885,8 @@ class AuthManager:
                 cursor.execute(
                     """
                     SELECT * FROM users
-                    WHERE (email = %s OR sso_id = %s) AND tenant_id = %s AND is_active = TRUE
+                    WHERE (email = %s OR sso_id = %s) AND tenant_id = %s
+                    AND is_active = TRUE
                 """,
                     (email, sso_id, tenant_id),
                 )
@@ -1127,6 +1151,63 @@ class AuthManager:
         conn.close()
         return user
 
+    def get_user_by_email(
+        self, email: str, tenant_id: Optional[str] = None
+    ) -> Optional[User]:
+        """Get user by email with optional tenant filtering"""
+        conn = self.get_conn()
+        cursor = conn.cursor()
+
+        if tenant_id:
+            if self.db_type == "postgres":
+                cursor.execute(
+                    "SELECT * FROM users WHERE email = %s AND tenant_id = %s",
+                    (email, tenant_id),
+                )
+            else:
+                cursor.execute(
+                    "SELECT * FROM users WHERE email = ? AND tenant_id = ?",
+                    (email, tenant_id),
+                )
+        else:
+            if self.db_type == "postgres":
+                cursor.execute("SELECT * FROM users WHERE email = %s", (email,))
+            else:
+                cursor.execute("SELECT * FROM users WHERE email = ?", (email,))
+
+        row = cursor.fetchone()
+        if not row:
+            conn.close()
+            return None
+
+        if self.db_type == "postgres":
+            user = User(
+                id=row["id"],
+                tenant_id=row["tenant_id"],
+                email=row["email"],
+                first_name=row["first_name"],
+                last_name=row["last_name"],
+                role=row["role"],
+                is_active=bool(row["is_active"]),
+                created_at=row["created_at"],
+                last_login=row["last_login"],
+            )
+        else:
+            user = User(
+                id=row[0],
+                tenant_id=row[1],
+                email=row[2],
+                first_name=row[4],
+                last_name=row[5],
+                role=row[6],
+                is_active=bool(row[7]),
+                created_at=row[9],
+                last_login=row[10],
+            )
+
+        conn.close()
+        return user
+
     def handle_entra_id_callback(
         self, code: str, state: str
     ) -> Tuple[bool, Optional[User], str]:
@@ -1150,7 +1231,10 @@ class AuthManager:
                 "scope": " ".join(self.entra_scopes),
             }
 
-            token_url = f"https://login.microsoftonline.com/{self.entra_tenant_id}/oauth2/v2.0/token"
+            token_url = (
+                f"https://login.microsoftonline.com/{self.entra_tenant_id}"
+                "/oauth2/v2.0/token"
+            )
             token_response = requests.post(token_url, data=token_data, timeout=30)
             token_response.raise_for_status()
             tokens = token_response.json()
@@ -1179,7 +1263,8 @@ class AuthManager:
                 cursor = conn.cursor()
                 if self.db_type == "postgres":
                     cursor.execute(
-                        "SELECT id FROM tenants WHERE subdomain = %s AND is_active = TRUE",
+                        "SELECT id FROM tenants WHERE subdomain = %s "
+                        "AND is_active = TRUE",
                         (subdomain,),
                     )
                 else:
@@ -1207,7 +1292,8 @@ class AuthManager:
                 cursor.execute(
                     """
                     SELECT * FROM users
-                    WHERE (email = %s OR sso_id = %s) AND tenant_id = %s AND is_active = TRUE
+                    WHERE (email = %s OR sso_id = %s) AND tenant_id = %s
+                    AND is_active = TRUE
                 """,
                     (email, object_id, tenant_id),
                 )
@@ -1285,7 +1371,7 @@ class AuthManager:
                 success, message = self.create_user(
                     tenant_id=tenant_id,
                     email=email,
-                    password="",  # nosec B106: No password for Entra ID users is intentional
+                    password="",  # nosec B106: No password for Entra ID users
                     first_name=first_name,
                     last_name=last_name,
                     role="user",
@@ -1374,7 +1460,10 @@ class AuthManager:
             # Test Azure OpenAI if configured
             if "azure_openai" in azure_config:
                 config = azure_config["azure_openai"]
-                test_url = f"{config['endpoint']}/openai/models?api-version={config['api_version']}"
+                test_url = (
+                    f"{config['endpoint']}/openai/models"
+                    f"?api-version={config['api_version']}"
+                )
                 headers = {
                     "api-key": str(config["api_key"]),
                     "Content-Type": "application/json",
@@ -1467,7 +1556,8 @@ class AuthManager:
             # API tokens
             try:
                 cursor.execute(
-                    "SELECT COUNT(*) FROM api_tokens WHERE expires_at > ? OR expires_at IS NULL",
+                    "SELECT COUNT(*) FROM api_tokens WHERE expires_at > ? "
+                    "OR expires_at IS NULL",
                     (datetime.now(),),
                 )
                 stats["api_tokens"] = cursor.fetchone()[0]
@@ -1476,14 +1566,15 @@ class AuthManager:
 
             return stats
 
-    def get_all_users_for_tenant(self, tenant_id: str) -> List[User]:
+    def get_all_users_for_tenant(self, tenant_id: str) -> List["User"]:
         """Get all users for a specific tenant (for admin view)"""
         with self.get_conn() as conn:
             cursor = conn.cursor()
             cursor.execute(
                 """
                 SELECT u.id, u.tenant_id, u.email, u.first_name, u.last_name,
-                       u.role, u.is_active, u.created_at, u.last_login, t.name as tenant_name
+                       u.role, u.is_active, u.created_at, u.last_login,
+                       t.name as tenant_name
                 FROM users u
                 LEFT JOIN tenants t ON u.tenant_id = t.id
                 WHERE u.tenant_id = ?
@@ -1518,7 +1609,8 @@ class AuthManager:
             cursor.execute(
                 """
                 SELECT id, name, subdomain, max_users, is_active, created_at,
-                       (SELECT COUNT(*) FROM users WHERE tenant_id = t.id AND is_active = 1) as user_count
+                       (SELECT COUNT(*) FROM users WHERE tenant_id = t.id
+                        AND is_active = 1) as user_count
                 FROM tenants t
                 WHERE id = ?
             """,
@@ -1533,10 +1625,43 @@ class AuthManager:
                     subdomain=row[2],
                     max_users=row[3],
                     is_active=bool(row[4]),
-                    created_at=datetime.fromisoformat(row[5]) if row[5] else None,
+                    created_at=(
+                        datetime.fromisoformat(row[5]) if row[5] else datetime.now()
+                    ),
+                    user_count=row[6],
+                )
+                return tenant
+
+            return None
+
+    def get_tenant_by_subdomain(self, subdomain: str) -> Optional[Tenant]:
+        """Get tenant by subdomain"""
+        with self.get_conn() as conn:
+            cursor = conn.cursor()
+            cursor.execute(
+                """
+                SELECT id, name, subdomain, max_users, is_active, created_at,
+                       (SELECT COUNT(*) FROM users WHERE tenant_id = t.id
+                        AND is_active = 1) as user_count
+                FROM tenants t
+                WHERE subdomain = ?
+            """,
+                (subdomain,),
+            )
+
+            row = cursor.fetchone()
+            if row:
+                tenant = Tenant(
+                    id=row[0],
+                    name=row[1],
+                    subdomain=row[2],
+                    max_users=row[3],
+                    is_active=bool(row[4]),
+                    created_at=(
+                        datetime.fromisoformat(row[5]) if row[5] else datetime.now()
+                    ),
+                    user_count=row[6],
                 )
-                # Add user count as extra attribute
-                tenant.user_count = row[6]
                 return tenant
 
             return None
