@@ -39,6 +39,7 @@ class PromptRepository(TenantAwareRepository[Prompt]):
                     content TEXT NOT NULL,
                     category TEXT DEFAULT 'Uncategorized',
                     tags TEXT DEFAULT '',
+                    visibility TEXT DEFAULT 'private' CHECK (visibility IN ('private', 'public')),
                     is_enhancement_prompt BOOLEAN DEFAULT FALSE,
                     created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
                     updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
@@ -70,6 +71,7 @@ class PromptRepository(TenantAwareRepository[Prompt]):
                     content TEXT NOT NULL,
                     category TEXT DEFAULT 'Uncategorized',
                     tags TEXT DEFAULT '',
+                    visibility TEXT DEFAULT 'private' CHECK (visibility IN ('private', 'public')),
                     is_enhancement_prompt BOOLEAN DEFAULT FALSE,
                     created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
                     updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
@@ -108,6 +110,7 @@ class PromptRepository(TenantAwareRepository[Prompt]):
             "content": entity.content,
             "category": entity.category,
             "tags": entity.tags,
+            "visibility": entity.visibility,
             "is_enhancement_prompt": entity.is_enhancement_prompt,
             "created_at": entity.created_at,
             "updated_at": entity.updated_at,
@@ -186,17 +189,21 @@ class PromptRepository(TenantAwareRepository[Prompt]):
         search_term: str,
         search_in: Optional[List[str]] = None,
         limit: Optional[int] = None,
+        user_id: Optional[str] = None,
+        include_public_from_tenant: bool = True,
     ) -> List[Prompt]:
         """
-        Search prompts by content, name, or title within current tenant.
+        Search prompts by content, name, or title within current tenant with visibility filtering.
 
         Args:
             search_term: Term to search for
             search_in: Fields to search in ('name', 'title', 'content', 'tags')
             limit: Maximum number of results
+            user_id: User ID for visibility filtering (optional)
+            include_public_from_tenant: Whether to include public prompts from other users
 
         Returns:
-            List of matching prompts
+            List of matching prompts with visibility filtering applied
         """
         self._ensure_tenant_context()
 
@@ -206,21 +213,45 @@ class PromptRepository(TenantAwareRepository[Prompt]):
         search_fields = search_in or ["name", "title", "content", "tags"]
 
         # Build search conditions
-        conditions = []
+        search_conditions = []
         params = [self.current_tenant_id]
 
         for field in search_fields:
             if self.db_manager.config.db_type.value == "postgres":
-                conditions.append(f"{field} ILIKE %s")
+                search_conditions.append(f"{field} ILIKE %s")
             else:
-                conditions.append(f"{field} LIKE ? COLLATE NOCASE")
+                search_conditions.append(f"{field} LIKE ? COLLATE NOCASE")
             params.append(f"%{search_term}%")
 
-        # Build query
-        where_clause = f"tenant_id = {'%s' if self.db_manager.config.db_type.value == 'postgres' else '?'}"
-        where_clause += f" AND ({' OR '.join(conditions)})"
+        # Build base conditions
+        base_conditions = [
+            f"tenant_id = {'%s' if self.db_manager.config.db_type.value == 'postgres' else '?'}"
+        ]
 
-        query = f"SELECT * FROM prompts WHERE {where_clause}"  # nosec B608: where_clause is built from controlled parameters
+        # Add search conditions
+        base_conditions.append(f"({' OR '.join(search_conditions)})")
+
+        # Add visibility filtering
+        if user_id and include_public_from_tenant:
+            # User's own prompts OR public prompts from tenant
+            visibility_condition = f"(user_id = {'%s' if self.db_manager.config.db_type.value == 'postgres' else '?'} OR visibility = 'public')"
+            base_conditions.append(visibility_condition)
+            params.append(user_id)
+        elif user_id:
+            # Only user's own prompts
+            base_conditions.append(
+                f"user_id = {'%s' if self.db_manager.config.db_type.value == 'postgres' else '?'}"
+            )
+            params.append(user_id)
+        elif include_public_from_tenant:
+            # Only public prompts
+            base_conditions.append("visibility = 'public'")
+
+        # Build final query
+        where_clause = " AND ".join(base_conditions)
+
+        # nosec B608: where_clause is built from controlled parameters
+        query = f"SELECT * FROM prompts WHERE {where_clause}"
         if limit:
             query += f" LIMIT {limit}"
 
@@ -237,7 +268,10 @@ class PromptRepository(TenantAwareRepository[Prompt]):
         """
         self._ensure_tenant_context()
 
-        query = "SELECT DISTINCT category FROM prompts WHERE tenant_id = ? ORDER BY category"
+        query = (
+            "SELECT DISTINCT category FROM prompts WHERE tenant_id = ? "
+            "ORDER BY category"
+        )
         if self.db_manager.config.db_type.value == "postgres":
             query = query.replace("?", "%s")
 
@@ -256,7 +290,10 @@ class PromptRepository(TenantAwareRepository[Prompt]):
         """
         self._ensure_tenant_context()
 
-        query = "SELECT DISTINCT tags FROM prompts WHERE tenant_id = ? AND tags IS NOT NULL AND tags != ''"
+        query = (
+            "SELECT DISTINCT tags FROM prompts WHERE tenant_id = ? "
+            "AND tags IS NOT NULL AND tags != ''"
+        )
         if self.db_manager.config.db_type.value == "postgres":
             query = query.replace("?", "%s")
 
@@ -293,7 +330,10 @@ class PromptRepository(TenantAwareRepository[Prompt]):
         total_prompts = total_result["count"] if total_result else 0
 
         # Enhancement prompts
-        enhancement_query = "SELECT COUNT(*) as count FROM prompts WHERE tenant_id = ? AND is_enhancement_prompt = ?"
+        enhancement_query = (
+            "SELECT COUNT(*) as count FROM prompts WHERE tenant_id = ? "
+            "AND is_enhancement_prompt = ?"
+        )
         if self.db_manager.config.db_type.value == "postgres":
             enhancement_query = enhancement_query.replace("?", "%s")
 
@@ -397,3 +437,197 @@ class PromptRepository(TenantAwareRepository[Prompt]):
         if prompt and prompt.id:
             return self.delete(prompt.id)
         return False
+
+    def find_all_with_visibility(
+        self,
+        include_enhancement_prompts: bool = True,
+        include_public_from_tenant: bool = True,
+        user_id: Optional[str] = None,
+        limit: Optional[int] = None,
+        offset: Optional[int] = None,
+        order_by: Optional[str] = None,
+        order_desc: bool = False,
+    ) -> List[Prompt]:
+        """
+        Find all prompts with visibility filtering.
+
+        - Always includes user's own prompts (private + public)
+        - Optionally includes public prompts from other users in the tenant
+
+        Args:
+            include_enhancement_prompts: Whether to include enhancement prompts
+            include_public_from_tenant: Whether to include public prompts from other users
+            user_id: User ID for filtering (if not provided, uses current tenant filtering)
+            limit: Maximum number of results
+            offset: Number of results to skip
+            order_by: Field to order by
+            order_desc: Whether to order in descending order
+
+        Returns:
+            List of prompts with visibility filtering applied
+        """
+        self._ensure_tenant_context()
+
+        # Build query with visibility conditions
+        query_parts = ["SELECT * FROM prompts"]
+        params = []
+
+        # Base tenant filtering
+        conditions = ["tenant_id = ?"]
+        params.append(self.current_tenant_id)
+
+        # Visibility filtering
+        if user_id and include_public_from_tenant:
+            # User's own prompts OR public prompts from tenant
+            visibility_condition = "(user_id = ? OR visibility = 'public')"
+            conditions.append(visibility_condition)
+            params.append(user_id)
+        elif user_id:
+            # Only user's own prompts
+            conditions.append("user_id = ?")
+            params.append(user_id)
+        elif include_public_from_tenant:
+            # Only public prompts
+            conditions.append("visibility = 'public'")
+
+        # Enhancement prompts filter
+        if not include_enhancement_prompts:
+            conditions.append("is_enhancement_prompt = ?")
+            params.append(False)
+
+        # Add WHERE clause
+        if conditions:
+            query_parts.append("WHERE " + " AND ".join(conditions))
+
+        # Add ORDER BY clause
+        if order_by:
+            direction = "DESC" if order_desc else "ASC"
+            query_parts.append(f"ORDER BY {order_by} {direction}")
+
+        # Add pagination
+        if limit:
+            query_parts.append(f"LIMIT {limit}")
+            if offset:
+                query_parts.append(f"OFFSET {offset}")
+
+        query = " ".join(query_parts)
+
+        # Convert to PostgreSQL syntax if needed
+        if self.db_manager.config.db_type.value == "postgres":
+            query = query.replace("?", "%s")
+
+        rows = self.db_manager.execute_query(query, tuple(params), fetch_all=True)
+        return [self._row_to_entity(row) for row in rows]
+
+    def find_public_prompts_in_tenant(
+        self,
+        include_enhancement_prompts: bool = True,
+        limit: Optional[int] = None,
+        offset: Optional[int] = None,
+        order_by: Optional[str] = None,
+        order_desc: bool = False,
+    ) -> List[Prompt]:
+        """
+        Find all public prompts within current tenant.
+
+        Args:
+            include_enhancement_prompts: Whether to include enhancement prompts
+            limit: Maximum number of results
+            offset: Number of results to skip
+            order_by: Field to order by
+            order_desc: Whether to order in descending order
+
+        Returns:
+            List of public prompts in the tenant
+        """
+        filters = {"visibility": "public"}
+        if not include_enhancement_prompts:
+            filters["is_enhancement_prompt"] = False
+
+        return self.find_all(
+            filters=filters,
+            limit=limit,
+            offset=offset,
+            order_by=order_by,
+            order_desc=order_desc,
+        )
+
+    def find_by_visibility(
+        self,
+        visibility: str,
+        user_id: Optional[str] = None,
+        limit: Optional[int] = None,
+    ) -> List[Prompt]:
+        """
+        Find prompts by visibility level.
+
+        Args:
+            visibility: 'private' or 'public'
+            user_id: Optional user ID for filtering
+            limit: Maximum number of results
+
+        Returns:
+            List of prompts with specified visibility
+        """
+        filters = {"visibility": visibility}
+        if user_id:
+            filters["user_id"] = user_id
+
+        return self.find_all(filters=filters, limit=limit)
+
+    def get_visibility_statistics(self) -> Dict[str, Any]:
+        """
+        Get visibility statistics for current tenant.
+
+        Returns:
+            Dictionary with visibility statistics
+        """
+        self._ensure_tenant_context()
+
+        # Total prompts
+        total_query = "SELECT COUNT(*) as count FROM prompts WHERE tenant_id = ?"
+        if self.db_manager.config.db_type.value == "postgres":
+            total_query = total_query.replace("?", "%s")
+
+        total_result = self.db_manager.execute_query(
+            total_query, (self.current_tenant_id,), fetch_one=True
+        )
+        total_prompts = total_result["count"] if total_result else 0
+
+        # Private prompts
+        private_query = (
+            "SELECT COUNT(*) as count FROM prompts WHERE tenant_id = ? "
+            "AND visibility = ?"
+        )
+        if self.db_manager.config.db_type.value == "postgres":
+            private_query = private_query.replace("?", "%s")
+
+        private_result = self.db_manager.execute_query(
+            private_query, (self.current_tenant_id, "private"), fetch_one=True
+        )
+        private_prompts = private_result["count"] if private_result else 0
+
+        # Public prompts
+        public_query = (
+            "SELECT COUNT(*) as count FROM prompts WHERE tenant_id = ? "
+            "AND visibility = ?"
+        )
+        if self.db_manager.config.db_type.value == "postgres":
+            public_query = public_query.replace("?", "%s")
+
+        public_result = self.db_manager.execute_query(
+            public_query, (self.current_tenant_id, "public"), fetch_one=True
+        )
+        public_prompts = public_result["count"] if public_result else 0
+
+        return {
+            "total_prompts": total_prompts,
+            "private_prompts": private_prompts,
+            "public_prompts": public_prompts,
+            "private_percentage": (
+                (private_prompts / total_prompts * 100) if total_prompts > 0 else 0
+            ),
+            "public_percentage": (
+                (public_prompts / total_prompts * 100) if total_prompts > 0 else 0
+            ),
+        }
